@@ -395,13 +395,64 @@ def bq_table_to_parquet(
     project=PROJECT_ID,
     partition=None,
     where=None,
+    spark_session=None,
     mode="overwrite",
 ):
     bq_table_to_df(
-        dataset, table_name, col_list, project=project, partition=partition, where=where
+        dataset,
+        table_name,
+        col_list,
+        project=project,
+        partition=partition,
+        where=where,
+        spark_session=spark_session,
     ).write.mode(mode).parquet(output_dir)
 
 
+def bq_table_to_csv(
+    dataset,
+    table_name,
+    output_dir,
+    col_list="*",
+    project=PROJECT_ID,
+    partition=None,
+    where=None,
+    spark_session=None,
+    mode="overwrite",
+):
+    bq_table_to_df(
+        dataset,
+        table_name,
+        col_list,
+        project=project,
+        partition=partition,
+        where=where,
+        spark_session=spark_session,
+    ).write.mode(mode).csv(output_dir)
+
+
+def bq_table_to_json(
+    dataset,
+    table_name,
+    output_dir,
+    col_list="*",
+    project=PROJECT_ID,
+    partition=None,
+    where=None,
+    spark_session=None,
+    mode="overwrite",
+):
+    bq_table_to_df(
+        dataset,
+        table_name,
+        col_list,
+        project=project,
+        partition=partition,
+        where=where,
+        spark_session=spark_session,
+    ).write.mode(mode).json(output_dir)
+
+
 def bq_table_to_pandas(
     dataset, table_name, col_list="*", project=PROJECT_ID, partition=None, where=None
 ):
@@ -484,10 +535,13 @@ def parquet_to_bq_table(
     partition_field=None,
     clustering_fields=None,
     mode="overwrite",
+    spark_session=None,
 ):
     try:
-        spark = get_spark()
-        df = spark.read.format("parquet").load(parquet_dir)
+        if not spark_session:
+            spark_session = get_spark()
+
+        df = spark_session.read.format("parquet").load(parquet_dir)
         _df_to_bq_table(
             df,
             dataset,
@@ -499,7 +553,7 @@ def parquet_to_bq_table(
             mode,
         )
     finally:
-        spark.stop()
+        spark_session.stop()
 
 
 def pandas_to_bq_table(
@@ -511,10 +565,13 @@ def pandas_to_bq_table(
     partition_field=None,
     clustering_fields=None,
     mode="overwrite",
+    spark_session=None,
 ):
     try:
-        spark = get_spark()
-        spark_df = spark.createDataFrame(pd_df)
+        if not spark_session:
+            spark_session = get_spark()
+
+        spark_df = spark_session.createDataFrame(pd_df)
         _df_to_bq_table(
             spark_df,
             dataset,
@@ -526,7 +583,7 @@ def pandas_to_bq_table(
             mode,
         )
     finally:
-        spark.stop()
+        spark_session.stop()
 
 
 def pandas_to_bq(
